@@ -1,8 +1,8 @@
 package App::Docmake;
-$App::Docmake::VERSION = '0.0801';
+$App::Docmake::VERSION = '0.0900';
+use 5.014;
 use strict;
 use warnings;
-use 5.014;
 
 use parent 'App::XML::DocBook::Docmake';
 
@@ -21,7 +21,7 @@ App::Docmake - translate DocBook/XML to other formats
 
 =head1 VERSION
 
-version 0.0801
+version 0.0900
 
 =head1 SYNOPSIS
 
@@ -57,14 +57,6 @@ L<https://metacpan.org/release/App-XML-DocBook-Builder>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-XML-DocBook-Builder>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -73,14 +65,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-XML-DocBook-Builder>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-XML-DocBook-Builder>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
